<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Categories';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Users = ReadUsers ();
    $Categories = ReadCategories ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    echo '<fieldset>
<legend><strong>Categories</strong></legend>
<table style="width: 100%; border: 0px">' . "\n";

    foreach ($Categories as $Category) {

      /* Show the name of the category */
      echo '<tr><td style="width: 30%">
' . $Category['long'] . '
</td><td style="width: 70%">' . "\n";

      /* Create the edit link only if the user is allowed to edit categories */
      if (UserCan ('edit_category')) {
        echo '<a href="edit.php?category=' . $Category['short'] . '">';
      }
      echo 'Edit';
      if (UserCan ('edit_category')) {
        echo '</a>';
      }

      echo ' | ';

      /* Create the link only if the user is allowed to delete categories
       * (and the category is not the default one, which cannot be deleted) */
      if ((UserCan ('delete_category')) && (strcmp ($Category['short'], 'general'))) {
        echo '<a href="confirm.php?category=' . $Category['short'] . '">';
      }
      echo 'Delete';
      if ((UserCan ('delete_category')) && (strcmp ($Category['short'], 'general'))) {
        echo '</a>';
      }

      echo '
</td></tr>' . "\n";
    }

    echo '</table>
</fieldset>' . "\n";

    /* Show the category creation link only if the user is allowed to create
     * categories */
    if (UserCan ('create_category')) {
      echo '<p><a href="create.php?category">Create a new category</a></p>' . "\n";
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
