<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Configuration';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }
    error_reporting (E_ALL);

    /* Read users and categories */
    $Users = ReadUsers ();
    $Categories = ReadCategories ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    /* Check the user is allowed to edit the configuration */
    if (UserCan ('edit_configuration')) {

      /* Load the blacklist */
      $Blacklist = ReadBlacklist ();

      /* Save the configuration */
      if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

        /* Default values for all the settings */
        $Config = array ('blog_title'               => '',
                         'blog_description'         => '',
                         'blog_url'                 => 'index.php',
                         'blog_language'            => 'en',
                         'posts_number'             => 5,
                         'posts_order'              => 'Reverse',
                         'comments_order'           => 'Chronological',
                         'trackbacks_order'         => 'Chronological',
                         'comments_default'         => 'Enabled',
                         'trackbacks_default'       => 'Enabled',
                         'blacklist_filter'         => 'Disabled',
                         'captcha_filter'           => 'Enabled',
                         'captcha_secret_key'       => RandomString (20),
                         'captcha_background_color' => '#ffffff',
                         'captcha_text_color'       => '#bab5b5',
                         'captcha_spiral_color'     => '#abcdef',
                         'captcha_outline_color'    => '#000000',
                         'allowed_tags'             => '<br>,<a>,<img>,<span>,<strong>,<em>,<b>,<i>',
                         'data_dir'                 => 'data/',
                         'time_offset'              => '+0',
                         'debug'                    => 0);

/*
          $Config[''] = str_replace ('\\', '\\\\', $Config['']);
          $Config[''] = str_replace ('\'', '\\\'', $Config['']);
          */

        /* Get the settings from the request, and escape any single quote
         * possibly found to avoid parsing errors on the file later*/
        if (isset ($_POST['blog_title'])) {
          $Config['blog_title'] = stripslashes ($_POST['blog_title']); 
          $Config['blog_title'] = str_replace ('\\', '\\\\', $Config['blog_title']);
          $Config['blog_title'] = str_replace ('\'', '\\\'', $Config['blog_title']);
        }
        if (isset ($_POST['blog_description'])) {
          $Config['blog_description'] = stripslashes ($_POST['blog_description']);
          $Config['blog_description'] = str_replace ('\\', '\\\\', $Config['blog_description']);
          $Config['blog_description'] = str_replace ('\'', '\\\'', $Config['blog_description']);
        }
        if (isset ($_POST['blog_url'])) {
          $Config['blog_url'] = stripslashes ($_POST['blog_url']);
          $Config['blog_url'] = str_replace ('\\', '\\\\', $Config['blog_url']);
          $Config['blog_url'] = str_replace ('\'', '\\\'', $Config['blog_url']);
        }
        if (isset ($_POST['blog_language'])) {
          $Config['blog_language'] = stripslashes ($_POST['blog_language']);
          $Config['blog_language'] = str_replace ('\\', '\\\\', $Config['blog_language']);
          $Config['blog_language'] = str_replace ('\'', '\\\'', $Config['blog_language']);
        }
        if (isset ($_POST['posts_number'])) {
          $Config['posts_number'] = stripslashes ($_POST['posts_number']);
          $Config['posts_number'] = str_replace ('\\', '\\\\', $Config['posts_number']);
          $Config['posts_number'] = str_replace ('\'', '\\\'', $Config['posts_number']);
        }
        if (isset ($_POST['posts_order'])) {
          $Config['posts_order'] = stripslashes ($_POST['posts_order']);
          $Config['posts_order'] = str_replace ('\\', '\\\\', $Config['posts_order']);
          $Config['posts_order'] = str_replace ('\'', '\\\'', $Config['posts_order']);
        }
        if (isset ($_POST['comments_order'])) {
          $Config['comments_order'] = stripslashes ($_POST['comments_order']);
          $Config['comments_order'] = str_replace ('\\', '\\\\', $Config['comments_order']);
          $Config['comments_order'] = str_replace ('\'', '\\\'', $Config['comments_order']);
        }
        if (isset ($_POST['trackbacks_order'])) {
          $Config['trackbacks_order'] = stripslashes ($_POST['trackbacks_order']);
          $Config['trackbacks_order'] = str_replace ('\\', '\\\\', $Config['trackbacks_order']);
          $Config['trackbacks_order'] = str_replace ('\'', '\\\'', $Config['trackbacks_order']);
        }
        if (isset ($_POST['comments_default'])) {
          $Config['comments_default'] = stripslashes ($_POST['comments_default']);
          $Config['comments_default'] = str_replace ('\\', '\\\\', $Config['comments_default']);
          $Config['comments_default'] = str_replace ('\'', '\\\'', $Config['comments_default']);
        }
        if (isset ($_POST['trackbacks_default'])) {
          $Config['trackbacks_default'] = stripslashes ($_POST['trackbacks_default']);
          $Config['trackbacks_default'] = str_replace ('\\', '\\\\', $Config['trackbacks_default']);
          $Config['trackbacks_default'] = str_replace ('\'', '\\\'', $Config['trackbacks_default']);
        }
        if (isset ($_POST['blacklist_filter'])) {
          $Config['blacklist_filter'] = stripslashes ($_POST['blacklist_filter']);
          $Config['blacklist_filter'] = str_replace ('\\', '\\\\', $Config['blacklist_filter']);
          $Config['blacklist_filter'] = str_replace ('\'', '\\\'', $Config['blacklist_filter']);
        }
        if (isset ($_POST['captcha_filter'])) {
          $Config['captcha_filter'] = stripslashes ($_POST['captcha_filter']);
          $Config['captcha_filter'] = str_replace ('\\', '\\\\', $Config['captcha_filter']);
          $Config['captcha_filter'] = str_replace ('\'', '\\\'', $Config['captcha_filter']);
        }
        /* Check it is not empty */
        if ((isset ($_POST['captcha_secret_key'])) && (strcmp ($_POST['captcha_secret_key'], ''))) {
          $Config['captcha_secret_key'] = stripslashes ($_POST['captcha_secret_key']);
          $Config['captcha_secret_key'] = str_replace ('\\', '\\\\', $Config['captcha_secret_key']);
          $Config['captcha_secret_key'] = str_replace ('\'', '\\\'', $Config['captcha_secret_key']);
        }
        if (isset ($_POST['captcha_background_color'])) {
          $Config['captcha_background_color'] = stripslashes ($_POST['captcha_background_color']);
          $Config['captcha_background_color'] = str_replace ('\\', '\\\\', $Config['captcha_background_color']);
          $Config['captcha_background_color'] = str_replace ('\'', '\\\'', $Config['captcha_background_color']);
        }
        if (isset ($_POST['captcha_text_color'])) {
          $Config['captcha_text_color'] = stripslashes ($_POST['captcha_text_color']);
          $Config['captcha_text_color'] = str_replace ('\\', '\\\\', $Config['captcha_text_color']);
          $Config['captcha_text_color'] = str_replace ('\'', '\\\'', $Config['captcha_text_color']);
        }
        if (isset ($_POST['captcha_spiral_color'])) {
          $Config['captcha_spiral_color'] = stripslashes ($_POST['captcha_spiral_color']);
          $Config['captcha_spiral_color'] = str_replace ('\\', '\\\\', $Config['captcha_spiral_color']);
          $Config['captcha_spiral_color'] = str_replace ('\'', '\\\'', $Config['captcha_spiral_color']);
        }
        if (isset ($_POST['captcha_outline_color'])) {
          $Config['captcha_outline_color'] = stripslashes ($_POST['captcha_outline_color']);
          $Config['captcha_outline_color'] = str_replace ('\\', '\\\\', $Config['captcha_outline_color']);
          $Config['captcha_outline_color'] = str_replace ('\'', '\\\'', $Config['captcha_outline_color']);
        }
        if (isset ($_POST['allowed_tags'])) {
          $Config['allowed_tags'] = stripslashes ($_POST['allowed_tags']);
          $Config['allowed_tags'] = str_replace ('\\', '\\\\', $Config['allowed_tags']);
          $Config['allowed_tags'] = str_replace ('\'', '\\\'', $Config['allowed_tags']);
        }
        if (isset ($_POST['data_dir'])) {
          $Config['data_dir'] = stripslashes ($_POST['data_dir']);
          $Config['data_dir'] = str_replace ('\\', '\\\\', $Config['data_dir']);
          $Config['data_dir'] = str_replace ('\'', '\\\'', $Config['data_dir']);
        }
        if (isset ($_POST['time_offset'])) {
          $Config['time_offset'] = stripslashes ($_POST['time_offset']);
          $Config['time_offset'] = str_replace ('\\', '\\\\', $Config['time_offset']);
          $Config['time_offset'] = str_replace ('\'', '\\\'', $Config['time_offset']);
        }
        if (isset ($_POST['debug'])) {
          $Config['debug'] = stripslashes ($_POST['debug']);
          $Config['debug'] = str_replace ('\\', '\\\\', $Config['debug']);
          $Config['debug'] = str_replace ('\'', '\\\'', $Config['debug']);
        }

        /* Get the new blacklist */
        if (isset ($_POST['blacklist'])) {
          $Blacklist = stripslashes ($_POST['blacklist']);

          $Blacklist = str_replace ("\r\n", "\n", $Blacklist);
          $Blacklist = PurgeNewline ($Blacklist);
          $Blacklist = explode ("\n", $Blacklist);
        }

        /* Create the configuration file */
        $File = '<?php' . '
  $BlogTitle = \'' . $Config['blog_title'] . '\';
  $BlogDescription = \'' . $Config['blog_description'] . '\';
  $BlogUrl = \'' . $Config['blog_url'] . '\';
  $BlogLanguage = \'' . $Config['blog_language'] . '\';
  $PostsNumber = ' . $Config['posts_number'] . ';
  $PostsOrder = \'' . $Config['posts_order'] . '\';
  $CommentsOrder = \'' . $Config['comments_order'] . '\';
  $TrackbacksOrder = \'' . $Config['trackbacks_order'] . '\';
  $CommentsDefault = \'' . $Config['comments_default'] . '\';
  $TrackbacksDefault = \'' . $Config['trackbacks_default'] . '\';
  $BlacklistFilter = \'' . $Config['blacklist_filter'] . '\';
  $CaptchaFilter = \'' . $Config['captcha_filter'] . '\';
  $CaptchaSecretKey = \'' . $Config['captcha_secret_key'] . '\';
  $CaptchaBackgroundColor = \'' . $Config['captcha_background_color'] . '\';
  $CaptchaTextColor = \'' . $Config['captcha_text_color'] . '\';
  $CaptchaSpiralColor = \'' . $Config['captcha_spiral_color'] . '\';
  $CaptchaOutlineColor = \'' . $Config['captcha_outline_color'] . '\';
  $AllowedTags = \'' . $Config['allowed_tags'] . '\';
  $DataDir = \'' . $Config['data_dir'] . '\';
  $TimeOffset = \'' . $Config['time_offset'] . '\';
  $Debug = ' . $Config['debug'] . ';
?' . ">\n";

        /* Write the new configuration to file */
        LockedFileWrite ($BlogRoot . 'config.php', $File);

        /* Create the new blacklist file */
        $File = implode ("\n", $Blacklist) . "\n";

        /* Write the blacklist to file */
        LockedFileWrite ($BlogRoot . 'blacklist', $File);

        /* Reload configuration */
        require ($BlogRoot . 'config.php');
        $Blacklist = ReadBlacklist ();
      }

      echo '<form method="post" action="configuration.php"><div>
<fieldset>
<legend><strong>Blog proprieties</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="blog_title">Title</label>
</td><td style="width: 70%">
<input type="text" id="blog_title" name="blog_title" value="' . htmlentities ($BlogTitle, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="blog_description">Description</label>
</td><td style="width: 70%">
<input type="text" id="blog_description" name="blog_description" value="' . htmlentities ($BlogDescription, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="blog_url"><acronym title="Uniform Resource Locator">URL</acronym></label>
</td><td style="width: 70%">
<input type="text" id="blog_url" name="blog_url" value="' . htmlentities ($BlogUrl, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="blog_language">Language</label>
</td><td style="width: 70%">
<input type="text" id="blog_language" name="blog_language" value="' . htmlentities ($BlogLanguage, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Presentation</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="posts_number">Posts number</label>
</td><td style="width: 70%">
<input type="text" id="posts_number" name="posts_number" value="' . $PostsNumber . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="posts_order">Posts order</label>
</td><td style="width: 70%">
<select id="posts_order" name="posts_order" style="width: 100%">
<option value="Reverse"';
      if (!strcmp ($PostsOrder, 'Reverse')) {
        echo ' selected="selected"';
      }
      echo '>Reverse</option>
<option value="Chronological"';
      if (!strcmp ($PostsOrder, 'Chronological')) {
        echo ' selected="selected"';
      }
      echo '>Chronological</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="comments_order">Comments order</label>
</td><td style="width: 70%">
<select id="comments_order" name="comments_order" style="width: 100%">
<option value="Chronological"';
      if (!strcmp ($CommentsOrder, 'Chronological')) {
        echo ' selected="selected"';
      }
      echo '>Chronological</option>
<option value="Reverse"';
      if (!strcmp ($CommentsOrder, 'Reverse')) {
        echo ' selected="selected"';
      }
      echo '>Reverse</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="trackbacks_order">Trackbacks order</label>
</td><td style="width: 70%">
<select id="trackbacks_order" name="trackbacks_order" style="width: 100%">
<option value="Chronological"';
      if (!strcmp ($TrackbacksOrder, 'Chronological')) {
        echo ' selected="selected"';
      }
      echo '>Chronological</option>
<option value="Reverse"';
      if (!strcmp ($TrackbacksOrder, 'Reverse')) {
        echo ' selected="selected"';
      }
      echo '>Reverse</option>
</select>
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Spam filters</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="blacklist_filter">Blacklist filter</label>
</td><td style="width: 70%">
<select id="blacklist_filter" name="blacklist_filter" style="width: 100%">
<option value="Enabled"';
      if (!strcmp ($BlacklistFilter, 'Enabled')) {
        echo ' selected="selected"';
      }
      echo '>Enabled</option>
<option value="Disabled"';
      if (!strcmp ($BlacklistFilter, 'Disabled')) {
        echo ' selected="selected"';
      }
      echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%; vertical-align: top">
<label for="blacklist">Blacklist</label>
</td><td style="width: 70%">
<textarea id="blacklist" name="blacklist" cols="50" rows="3" style="width: 100%">' . htmlentities (implode ("\n", $Blacklist), ENT_COMPAT, 'UTF-8') . '</textarea>
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_filter">Captcha filter</label>
</td><td style="width: 70%">
<select id="captcha_filter" name="captcha_filter" style="width: 100%">
<option value="Enabled"';
      if (!strcmp ($CaptchaFilter, 'Enabled')) {
        echo ' selected="selected"';
      }
      echo '>Enabled</option>
<option value="Disabled"';
      if (!strcmp ($CaptchaFilter, 'Disabled')) {
        echo ' selected="selected"';
      }
      echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_secret_key">Captcha secret key</label>
</td><td style="width: 70%">
<input type="text" id="captcha_secret_key" name="captcha_secret_key" value="' . htmlentities ($CaptchaSecretKey, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_background_color">Captcha background color</label>
</td><td style="width: 70%">
<input type="text" id="captcha_background_color" name="captcha_background_color" value="' . htmlentities ($CaptchaBackgroundColor, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_text_color">Captcha text color</label>
</td><td style="width: 70%">
<input type="text" id="captcha_text_color" name="captcha_text_color" value="' . htmlentities ($CaptchaTextColor, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_spiral_color">Captcha spiral color</label>
</td><td style="width: 70%">
<input type="text" id="captcha_spiral_color" name="captcha_spiral_color" value="' . htmlentities ($CaptchaSpiralColor, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="captcha_outline_color">Captcha outline color</label>
</td><td style="width: 70%">
<input type="text" id="captcha_outline_color" name="captcha_outline_color" value="' . htmlentities ($CaptchaOutlineColor, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Options</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="comments_default">Comments default</label>
</td><td style="width: 70%">
<select id="comments_default" name="comments_default" style="width: 100%">
<option value="Enabled"';
      if (!strcmp ($CommentsDefault, 'Enabled')) {
        echo ' selected="selected"';
      }
      echo '>Enabled</option>
<option value="Disabled"';
      if (!strcmp ($CommentsDefault, 'Disabled')) {
        echo ' selected="selected"';
      }
      echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="trackbacks_default">Trackbacks default</label>
</td><td style="width: 70%">
<select id="trackbacks_default" name="trackbacks_default" style="width: 100%">
<option value="Enabled"';
      if (!strcmp ($TrackbacksDefault, 'Enabled')) {
        echo ' selected="selected"';
      }
      echo '>Enabled</option>
<option value="Disabled"';
      if (!strcmp ($TrackbacksDefault, 'Disabled')) {
        echo ' selected="selected"';
      }
      echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="allowed_tags">Allowed tags</label>
</td><td style="width: 70%">
<input type="text" id="allowed_tags" name="allowed_tags" value="' . htmlentities ($AllowedTags, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="data_dir">Data dir</label>
</td><td style="width: 70%">
<input type="text" id="data_dir" name="data_dir" value="' . htmlentities ($DataDir, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="time_offset">Time offset</label>
</td><td style="width: 70%">
<input type="text" id="time_offset" name="time_offset" value="' . htmlentities ($TimeOffset, ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="debug">Debug</label>
</td><td style="width: 70%">
<select id="debug" name="debug" style="width: 100%">
<option value="0"';
      if ($Debug == 0) {
        echo ' selected="selected"';
      }
      echo '>Disabled</option>
<option value="1"';
      if ($Debug == 1) {
        echo ' selected="selected"';
      }
      echo '>Enabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save configuration" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>
</div></form>' . "\n";
    }

    /* The user is not allowed */
    else {
      echo '<p>You are not allowed to edit the configuration.</p>' . "\n";
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
  }
?>
