<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Confirm';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Categories = ReadCategories ();
    $Users = ReadUsers ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    /* Ask confirmation for a post deletion */
    if (!strcmp ($Context, 'post')) {

      $PostId = $Query;

      /* Parse the post (also checks for its existence) */
      $Post = ParsePost ($PostId);

      /* The post exists */
      if ($Post != NULL) {

        /* The user is allowed to delete posts, or is the author of the post */
        if ((UserCan ('delete_post')) || (!strcmp ($Post['author'], $UserLogin))) {

          echo '<p>Are you sure you want to delete this post?</p>
<p>Deleting the post will cause also all the comments and trackbacks related
to this post to be deleted.</p>
<form method="post" action="delete.php?post=' . $Query . '"><div>
<input type="hidden" name="confirm" value="yes" />
<input type="submit" value="Confirm" />
</div></form>' . "\n";
        }

        else {
          echo '<p>You are not allowed to delete this post.</p>' . "\n";
        }
      }
      else {
        echo '<p>The post doesn\'t exists.</p>' . "\n";
      }
    }

    /* Comment deletion */
    else if (!strcmp ($Context, 'comment')) {

      list ($PostId, $CommentId) = explode ('-', $Query);

      /* Parse the comments (also checks for its existence) */
      $Comment = ParseComment ($PostId, $CommentId);

      /* The comment exists */
      if ($Comment != NULL) {

        /* The user is allowed to delete comments, or is the author of the
         * comment */
        if ((UserCan ('delete_comment')) || (!strcmp ($Comment['author'], $UserLogin))) {

          echo '<p>Are you sure you want to delete this comment?</p>
<form method="post" action="delete.php?comment=' . $Query . '"><div>
<input type="hidden" name="confirm" value="yes" />
<input type="submit" value="Confirm" />
</div></form>' . "\n";
        }

        else {
          echo '<p>You are not allowed to delete this comment.</p>' . "\n";
        }
      }
      else {
        echo '<p>The comment doesn\'t exists.</p>' . "\n";
      }
    }

    /* Trackback deletion */
    else if (!strcmp ($Context, 'trackback')) {

      list ($PostId, $TrackbackId) = explode ('-', $Query);

      /* Check the trackback exists */
      if (IsTrackback ($PostId, $TrackbackId)) {

        /* Make sure the user is allowed to delete trackbacks */
        if (UserCan ('delete_trackback'))

          echo '<p>Are you sure you want to delete this trackback?</p>
<form method="post" action="delete.php?trackback=' . $Query . '"><div>
<input type="hidden" name="confirm" value="yes" />
<input type="submit" value="Confirm" />
</div></form>' . "\n";

        else {
          echo '<p>You are not allowed to delete this trackback.</p>' . "\n";
        }
      }
      else {
        echo '<p>The trackback doesn\'t exists.</p>' . "\n";
      }
    }

    /* Category deletion */
    else if (!strcmp ($Context, 'category')) {

      /* Check the category exists */
      if (isset ($Categories[$Query])) {

        /* The default category "general" cannot be deleted */
        if (!strcmp ($Query, 'general')) {
          echo '<p>You cannot delete the default category.</p>' . "\n";
        }

        else {

          /* The user is allowed to delete categories */
          if (UserCan ('delete_category')) {

            echo '<p>Are you sure you want to delete this category?</p>
<p>All posts in this category will fall to the default category "general".</p>
<form method="post" action="delete.php?category=' . $Query . '"><div>
<input type="hidden" name="confirm" value="yes" />
<input type="submit" value="Confirm" />
</div></form>' . "\n";
          }

          else {
            echo '<p>You are not allowed to delete this category.</p>' . "\n";
          }
        }
      }
      else {
        echo '<p>The category doesn\'t exists.</p>' . "\n";
      }
    }

    /* User deletion */
    else if (!strcmp ($Context, 'user')) {

      /* Check the category exists */
      if (isset ($Users[$Query])) {

        /* Nobody can delete the anonymous user */
        if (!strcmp ($Query, 'anonymous')) {
          echo '<p>You cannot delete the anonymous user.</p>' . "\n";
        }

        else {

          /* The user is allowed to delete other users */
          if (UserCan ('delete_user')) {

            echo '<p>Are you sure you want to delete this user?</p>
<p>This will delete also all of his posts and comments.</p>
<form method="post" action="delete.php?user=' . $Query . '"><div>
<input type="hidden" name="confirm" value="yes" />
<input type="submit" value="Confirm" />
</div></form>' . "\n";
          }

          else {
            echo '<p>You are not allowed to delete this user.</p>' . "\n";
          }
        }
      }
      else {
        echo '<p>The user doesn\'t exists.</p>' . "\n";
      }
    }
    
    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
