<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Create';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Users = ReadUsers ();
    $Categories = ReadCategories ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    /* We are creating a post */
    if (!strcmp ($Context, 'post')) {

      /* The user can create a post */
      if (UserCan ('create_post')) {

        /* The form was submitted */
        if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

          /* Redirect to main page after creating post */
          header ('Location: show.php');

          $PostId = '';
          $Title = '';
          $Category = '';
          $Body = '';
          $Comments = $CommentsDefault;
          $Trackbacks = $TrackbacksDefault;
          $Urls = '';
          $Excerpt = '';

          if (isset ($_POST['title'])) {
            $Title = stripslashes ($_POST['title']);
          }
          if (isset ($_POST['category'])) {
            $Category = stripslashes ($_POST['category']);
          }
          if (isset ($_POST['body'])) {
            $Body = stripslashes ($_POST['body']);
          }
          if (isset ($_POST['comments'])) {
            $Comments = stripslashes ($_POST['comments']);
          }
          if (isset ($_POST['trackbacks'])) {
            $Trackbacks = stripslashes ($_POST['trackbacks']);
          }
          if (isset ($_POST['urls'])) {
            $Urls = stripslashes ($_POST['urls']);
          }
          if (isset ($_POST['excerpt'])) {
            $Excerpt = stripslashes ($_POST['excerpt']);
          }

          /* The timestamp must be edited */
          if (isset ($_POST['edit_timestamp'])) {

            /* Get the selected timestamp */
            if (isset ($_POST['timestamp'])) {
              $PostId = stripslashes ($_POST['timestamp']);
            }

            /* Check the timestamp is valid */
            if ((!IsNumber ($PostId)) || (strlen ($PostId) != 14)) {
              $PostId = '';
            }
          }

          /* Use current date/time */
          if (!strcmp ($PostId, '')) {
            $Now = strtotime (TimeOffsetString (), time ());
            $PostId = strftime ('%Y%m%d%H%M%S', $Now);
          }

          /* The author of this post is the user logged in */
          $AuthorLogin = $UserLogin;

          /* Edit the body */
          if (isset ($_POST['preserve_linebreaks'])) {
            $Body = str_replace ("\r\n", "<br />\n", $Body);
          }
          else {
            $Body = str_replace ("\r\n", "\n", $Body);
          }
          $Body = PurgeNewline ($Body);

          /* This trick is to avoid fake meta data */
          $Body = str_replace ('AUTHOR:', ' AUTHOR:', $Body);
          $Body = str_replace ('CATEGORY:', ' CATEGORY:', $Body);
          $Body = str_replace ('TITLE:', ' TITLE:', $Body);

          /* We are not going to overwrite any existing post */
          if (!is_dir ($BlogRoot . $DataDir . $PostId)) {

            /* Create directories for post, comments and trackbacks */
            mkdir ($BlogRoot . $DataDir . $PostId, 0755);
            mkdir ($BlogRoot . $DataDir . $PostId . '/comments', 0755);
            mkdir ($BlogRoot . $DataDir . $PostId . '/trackbacks', 0755);

            /* Comments are disabled for this post */
            if (!strcmp ($Comments, 'Disabled')) {
              touch ($BlogRoot . $DataDir . $PostId . '/comments/disabled');
            }

            /* Trackbacks are disabled for this post */
            if (!strcmp ($Trackbacks, 'Disabled')) {
              touch ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled');
            }

            /* Create the post file*/
            $File = 'AUTHOR: ' . $AuthorLogin . '
CATEGORY: ' . $Category . '
TITLE: ' . $Title . '
' . $Body . "\n";

            /* Write the post to file */
            LockedFileWrite ($BlogRoot . $DataDir . $PostId . '/post', $File);
          }

          /* Get URLs to ping */
          $Urls = explode (' ', $Urls);

          /* There are URLs to ping */
          if (count ($Urls) > 0) {

            foreach ($Urls as $Url) {

              /* Send trackback ping to URL */
              SendPing ($Url, $PostId, $Title, $Excerpt);
            }
          }
        }

        else {

          /* Show the form */
          echo ' <form method="post" action="create.php?post"><div>
<fieldset>
<legend><strong>Content</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="title">Title</label>
</td><td style="width: 70%">
<input id="title" name="title" type="text" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="category">Category</label>
</td><td style="width: 70%">
<select id="category" name="category" style="width: 100%">' . "\n";
          foreach ($Categories as $Category) {
            echo '<option value="' . $Category['short'] . '">' . $Category['long'] . '</option>' . "\n";
          }
          echo '</select>
</td></tr>
<tr><td style="width: 30%; vertical-align: top">
<label for="body">Body</label>
</td><td style="width: 70%">
<textarea id="body" name="body" cols="50" rows="10" style="width: 100%">
</textarea>
</td></tr>
<tr><td style="width: 30%">
&nbsp;
</td><td style="width: 70%">
<label for="preserve_linebreaks">Preserve linebreaks?</label>
<input type="checkbox" name="preserve_linebreaks" id="preserve_linebreaks" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Create post" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Options</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="timestamp">Timestamp</label>
</td><td style="width: 70%">
<input id="timestamp" name="timestamp" type="text" />
<label for="edit_timestamp">Edit timestamp?</label>
<input id="edit_timestamp" name="edit_timestamp" type="checkbox" />
</td></tr>
<tr><td style="width: 30%">
<label for="comments">Comments</label>
</td><td style="width: 70%">
<select id="comments" name="comments">
<option value="Enabled"';
          if (!strcmp ($CommentsDefault, 'Enabled')) {
            echo ' selected="selected"';
          }
          echo '>Enabled</option>
<option value="Disabled"';
          if (!strcmp ($CommentsDefault, 'Disabled')) {
            echo ' selected="selected"';
          }
          echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="trackbacks">Trackbacks</label>
</td><td style="width: 70%">
<select id="trackbacks" name="trackbacks">
<option value="Enabled"';
          if (!strcmp ($TrackbacksDefault, 'Enabled')) {
            echo ' selected="selected"';
          }
          echo '>Enabled</option>
<option value="Disabled"';
          if (!strcmp ($TrackbacksDefault, 'Disabled')) {
            echo ' selected="selected"';
          }
          echo '>Disabled</option>
</select>
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Send pings</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="urls"><acronym title="Uniform Resource Locator">URL</acronym>s to ping</label>
</td><td style="width: 70%">
<input id="urls" name="urls" type="text" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%" valign="top">
<label for="excerpt">Excerpt</label>
</td><td style="width: 70%">
<textarea id="excerpt" name="excerpt" cols="50" rows="2" style="width: 100%">
</textarea>
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Create post" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>
      </div></form>' . "\n";
        }
      }

      /* The user can't create a post */
      else {
        echo '<p>You are not allowed to create a post.</p>' . "\n";
      }
    }

    /* We are creating a category */
    else if (!strcmp ($Context, 'category')) {

      /* The user can create a category */
      if (UserCan ('create_category')) {

        /* The form was submitted */
        if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

          /* Redirect to categories page */
          header ('Location: categories.php');

          $Category = array ('short' => '',
                             'long'  => '',
                             'users' => '*');

          if (isset ($_POST['short'])) {
            $Category['short'] = stripslashes ($_POST['short']);
          }
          if (isset ($_POST['long'])) {
            $Category['long'] = stripslashes ($_POST['long']);
          }

          /* Check the category doesn't exist before creating it */
          if (!isset ($Categories[$Category['short']])) {

            /* Add the category to the list and write the list to file */
            $Categories[$Category['short']] = $Category;
            WriteCategories ();
          }
        }

        else {

          /* Show the form */
          echo '<form method="post" action="create.php?category"><div>
<fieldset>
<legend><strong>Category info</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="short">Short name</label>
</td><td style="width: 70%">
<input type="text" id="short" name="short" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="long">Long name</label>
</td><td style="width: 70%">
<input type="text" id="long" name="long" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Create category" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>
</div></form>' . "\n";
        }
      }

      /* The user can't create a category */
      else {
        echo '<p>You are not allowed to create a category.</p>' . "\n";
      }
    }

    /* Create an user */
    else if (!strcmp ($Context, 'user')) {

      /* The user can create another user */
      if (UserCan ('create_user')) {

        /* The user is submitting the form */
        if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

          /* Redirect to users page */
          header ('Location: users.php');

          $User = array ('login'    => '',
                         'password' => '',
                         'name'     => '',
                         'link'     => '',
                         'perms'    => '');

          if (isset ($_POST['login'])) {
            $User['login'] = stripslashes ($_POST['login']);
          }
          if (isset ($_POST['password'])) {

            /* Check the password was confirmed correctly */
            if (!strcmp ($_POST['password'], $_POST['confirm_password'])) {
              $User['password'] = md5 (stripslashes ($_POST['password']));
            }
          }
          if (isset ($_POST['name'])) {
            $User['name'] = stripslashes ($_POST['name']);
          }
          if (isset ($_POST['link'])) {
            $User['link'] = stripslashes ($_POST['link']);
          }

          /* Start with no permissions */
          $Perms = '0000000';

          if (isset ($_POST['create_post'])) {
            $Perms[0] = $Perms[0] + 4;
          }
          if (isset ($_POST['edit_post'])) {
            $Perms[0] = $Perms[0] + 2;
          }
          if (isset ($_POST['delete_post'])) {
            $Perms[0] = $Perms[0] + 1;
          }
          if (isset ($_POST['delete_comment'])) {
            $Perms[1] = $Perms[1] + 1; 
          }
          if (isset ($_POST['delete_trackback'])) {
            $Perms[2] = $Perms[2] + 1; 
          }
          if (isset ($_POST['create_category'])) {
            $Perms[3] = $Perms[3] + 4; 
          }
          if (isset ($_POST['edit_category'])) {
            $Perms[3] = $Perms[3] + 2; 
          }
          if (isset ($_POST['delete_category'])) {
            $Perms[3] = $Perms[3] + 1; 
          }
          if (isset ($_POST['create_user'])) {
            $Perms[4] = $Perms[4] + 4; 
          }
          if (isset ($_POST['edit_user'])) {
            $Perms[4] = $Perms[4] + 2; 
          }
          if (isset ($_POST['delete_user'])) {
            $Perms[4] = $Perms[4] + 1; 
          }
          if (isset ($_POST['edit_configuration'])) {
            $Perms[6] = $Perms[6] + 2; 
          }

          $User['perms'] = $Perms;

          /* Check the user doesn't already exist */
          if (!isset ($Users[$User['login']])) {

            /* Check the password was confirmed correctly */
            if (strcmp ($User['password'], '')) {

              /* Add the user to the users list, and write the updated one
               * to file*/
              $Users[$User['login']] = $User;
              WriteUsers ();
            }
          }
        }

        else {
          echo '<form method="post" action="create.php?user"><div>
<fieldset>
<legend><strong>User info</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="login">Login</label>
</td><td style="width: 70%">
<input type="text" id="login" name="login" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="name">Name</label>
</td><td style="width: 70%">
<input type="text" id="name" name="name" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="link">Link</label>
</td><td style="width: 70%">
<input type="text" id="link" name="link" value="http://" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="password">Password</label>
</td><td style="width: 70%">
<input type="password" id="password" name="password" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="confirm_password">Confirm password</label>
</td><td style="width: 70%">
<input type="password" id="confirm_password" name="confirm_password" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Create user" />
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Permissions</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
Posts
</td><td style="width: 20%">
<label for="create_post">Create</label>
<input type="checkbox" id="create_post" name="create_post" checked="checked" />
</td><td style="width: 20%">
<label for="edit_post">Edit</label>
<input type="checkbox" id="edit_post" name="edit_post" />
</td><td style="width: 20%">
<label for="delete_post">Delete</label>
<input type="checkbox" id="delete_post" name="delete_post" />
</td></tr>
<tr><td style="width: 30%">
Comments
</td><td style="width: 20%">
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="delete_comment">Delete</label>
<input type="checkbox" id="delete_comment" name="delete_comment" />
</td></tr>
<tr><td style="width: 30%">
Trackbacks
</td><td style="width: 20%">
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="delete_trackback">Delete</label>
<input type="checkbox" id="delete_trackback" name="delete_trackback" />
</td></tr>
<tr><td style="width: 30%">
Categories
</td><td style="width: 20%">
<label for="create_category">Create</label>
<input type="checkbox" id="create_category" name="create_category" />
</td><td style="width: 20%">
<label for="edit_category">Edit</label>
<input type="checkbox" id="edit_category" name="edit_category" />
</td><td style="width: 20%">
<label for="delete_category">Delete</label>
<input type="checkbox" id="delete_category" name="delete_category" />
</td></tr>
<tr><td style="width: 30%">
Users
</td><td style="width: 20%">
<label for="create_user">Create</label>
<input type="checkbox" id="create_user" name="create_user" />
</td><td style="width: 20%">
<label for="edit_user">Edit</label>
<input type="checkbox" id="edit_user" name="edit_user" />
</td><td style="width: 20%">
<label for="delete_user">Delete</label>
<input type="checkbox" id="delete_user" name="delete_user" />
</td></tr>
<tr><td style="width: 30%">
Configuration
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="edit_configuration">Edit</label>
<input type="checkbox" id="edit_configuration" name="edit_configuration" />
</td><td style="width: 20%">
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Create user" />
</td></tr>
</table>
</fieldset>
</div></form>' . "\n";
        }
      }

      /* The user cannot create another user */
      else {
        echo '<p>You are not allowed to create an user.</p>' . "\n";
      }
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
