<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Delete';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Users = ReadUsers ();
    $Categories = ReadCategories ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    /* Check the user has confirmed the deletion */
    if ((isset ($_POST['confirm'])) && (!strcmp ($_POST['confirm'], 'yes'))) {

      /* We are deleting a post */
      if (!strcmp ($Context, 'post')) {

        $PostId = $Query;
        header ('Location: show.php');

        /* Parse the post and checks for it existence */
        $Post = ParsePost ($Query);

        /* The post exists */
        if ($Post != NULL) {

          /* The user can delete posts, or he is the author of the post */
          if ((UserCan ('delete_post')) || (!strcmp ($Post['author'], $UserLogin))) {

            /* Get all the comments for this post */
            $PostComments = $Comments[$PostId];
            unset ($PostComments['post_id']);

            /* Delete every comment */
            foreach ($PostComments as $CommentId) {
              unlink ($BlogRoot . $DataDir . $PostId . '/comments/' . $CommentId);
            }

            /* Delete the flag file (if it exists) and the comments
             * directory */
            if (is_file ($BlogRoot . $DataDir . $PostId . '/comments/disabled')) {
              unlink ($BlogRoot . $DataDir . $PostId . '/comments/disabled');
            }
            rmdir ($BlogRoot . $DataDir . $PostId . '/comments');

            /* Get all the trackbacks for the post */
            $PostTrackbacks = $Trackbacks[$PostId];
            unset ($PostTrackbacks['post_id']);

            /* Delete every trackback */
            foreach ($PostTrackbacks as $TrackbackId) {
              unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/' . $TrackbackId);
            }

            /* Delete the flag file (if it exists) and the trackbacks
             * directory */
            if (file_exists ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled')) {
              unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled');
            }
            rmdir ($BlogRoot . $DataDir . $PostId . '/trackbacks');

            /* Remove the post file and the post directory */
            unlink ($BlogRoot . $DataDir . $PostId . '/post');
            rmdir ($BlogRoot . $DataDir . $PostId);
          }
        }
      }

      /* We are deleting a comment */
      else if (!strcmp ($Context, 'comment')) {

        list ($PostId, $CommentId) = explode ('-', $Query);
        header ('Location: show.php?comment=' . $PostId);

        /* Parse comment */
        $Comment = ParseComment ($PostId, $CommentId);

        if ($Comment != NULL) {

          /* Check the user is allowed to delete this comment */
          if ((UserCan ('delete_comment')) || (!strcmp ($Comment['author'], $UserLogin))) {

            /* Delete the comment file */
            unlink ($BlogRoot . $DataDir . $PostId . '/comments/' . $CommentId);
          }
        }
      }

      /* We are deleting a trackback */
      else if (!strcmp ($Context, 'trackback')) {

        list ($PostId, $TrackbackId) = explode ('-', $Query);
        header ('Location: show.php?trackback=' . $PostId);

        /* Parse trackback */
        $Trackback = ParseTrackback ($PostId, $TrackbackId);

        if ($Trackback != NULL) {

          /* Check the user can delete trackbacks */
          if (UserCan ('delete_trackback'))

            /* Delete the trackback file */
            unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/' . $TrackbackId);
        }
      }

      /* We are deleting a category */
      else if (!strcmp ($Context, 'category')) {

        header ('Location: categories.php');

        /* Check the category exists */
        if (isset ($Categories[$Query])) {

          /* Check the user can delete categories, and that the category we
           * are deleting is not the default one */
          if ((UserCan ('delete_category')) && (strcmp ($Query, 'general'))) {

            /* Get all the posts belonging to the category */
            $PostsList = GetPostsList ($Context, $Query);


            foreach ($PostsList as $PostId) {

              /* Read the post from file */
              $Post = ParsePost ($PostId);

              /* Change the post's category to the default one */
              $Post['category'] = 'general';

              $File = 'AUTHOR: ' . $Post['author'] . '
CATEGORY: ' . $Post['category'] . '
TITLE: ' . $Post['title'] . '
' . $Post['body'] . "\n";

              /* Save the updated file */
              LockedFileWrite ($BlogRoot . $DataDir . $PostId . '/post', $File);
            }

            /* Remove the category, and save the list to file */
            unset ($Categories[$Query]);
            WriteCategories ();
          }
        }
      }

      /* We are deleting a user */
      else if (!strcmp ($Context, 'user')) {

        header ('Location: users.php');

        /* Check the user is allowed to delete other users, and that the user
         * we are trying to delete is not the default one */
        if ((UserCan ('delete_user')) && (strcmp ($Query, 'anonymous'))) {

          /* Get all the posts whose author is the user we are deleting */
          $PostsList = GetPostsList ('author', $Query);

          foreach ($PostsList as $PostId) {

            /* Get all the comments for this post */
            $PostComments = $Comments[$PostId];
            unset ($PostComments['post_id']);

            /* Delete every comment */
            foreach ($PostComments as $CommentId) {
              unlink ($BlogRoot . $DataDir . $PostId . '/comments/' . $CommentId);
            }

            /* Delete the flag file (if it exists) and the comments
             * directory */
            if (is_file ($BlogRoot . $DataDir . $PostId . '/comments/disabled')) {
              unlink ($BlogRoot . $DataDir . $PostId . '/comments/disabled');
            }
            rmdir ($BlogRoot . $DataDir . $PostId . '/comments');

            /* Get all the trackbacks for the post */
            $PostTrackbacks = $Trackbacks[$PostId];
            unset ($PostTrackbacks['post_id']);

            /* Delete every trackback */
            foreach ($PostTrackbacks as $TrackbackId) {
              unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/' . $TrackbackId);
            }

            /* Delete the flag file (if it exists) and the trackbacks
             * directory */
            if (file_exists ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled')) {
              unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled');
            }

            /* Remove the post file and the post directory */
            unlink ($BlogRoot . $DataDir . $PostId . '/post');
            rmdir ($BlogRoot . $DataDir . $PostId);
          }

          /* Read again all posts, comments and trackbacks */
          $Posts = ReadPosts ();
          $Comments = ReadComments ();
          $Trackbacks = ReadTrackbacks ();


          foreach ($Posts as $PostId) {

            /* Get all comments for this post */
            $PostComments = $Comments[$PostId];
            unset ($PostComments['post_id']);

            foreach ($PostComments as $CommentId) {

              /* Parse the comment */
              $Comment = ParseComment ($PostId, $CommentId);

              /* If the author of the comment is the same user we are
               * deleting, delete the comment file */
              if (!strcmp ($Comment['author'], $Query)) {
                unlink ($BlogRoot . $DataDir . $PostId . '/comments/' . $CommentId);
              }
            }
          }

          /* Remove the user from the list, and write the updated users list
           * to file*/
          unset ($Users[$Query]);
          WriteUsers ();
        }
      }
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
