<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Edit';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Categories = ReadCategories ();
    $Users = ReadUsers ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Get context and query */
    $Context = GetContext ();
    $Query = GetQuery ($Context);

    /* We are editing a post */
    if (!strcmp ($Context, 'post')) {

      $PostId = $Query;

      /* Parse post */
      $Post = ParsePost ($PostId);

      if ($Posts != NULL) {

        /* The user can edit the post or is the author of the post */
        if ((UserCan ('edit_post')) || (!strcmp ($Post['author'], $UserLogin))) {

	      /* The form was submitted */
          if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

            /* Redirect to main page */
            header ('Location: show.php');

            $AuthorLogin = $Post['author'];
            $Title = '';
            $Category = '';
            $Body = '';
            $Comments = $CommentsDefault;
            $Trackbacks = $TrackbacksDefault;

            if (isset ($_POST['title'])) {
              $Title = stripslashes ($_POST['title']);
            }
            if (isset ($_POST['category'])) {
              $Category = stripslashes ($_POST['category']);
            }
            if (isset ($_POST['body'])) {
              $Body = stripslashes ($_POST['body']);
            }
            if (isset ($_POST['comments'])) {
              $Comments = stripslashes ($_POST['comments']);
            }
            if (isset ($_POST['trackbacks'])) {
              $Trackbacks = stripslashes ($_POST['trackbacks']);
            }

            /* The timestamp must be edited */
            if (isset ($_POST['edit_timestamp'])) {

              /* Get the selected timestamp */
              if (isset ($_POST['timestamp'])) {
                $PostId = stripslashes ($_POST['timestamp']);
              }

              /* Check the timestamp is valid */
              if ((!IsNumber ($PostId)) || (strlen ($PostId) != 14)) {
                $PostId = $Query;
              }
            }

            /* Move the post if editing timestamp */
            if (strcmp ($PostId, $Query)) {
              rename ($BlogRoot . $DataDir . $Query , $BlogRoot . $DataDir . $PostId);
            }

            /* Edit the body */
            if (isset ($_POST['preserve_linebreaks'])) {
              $Body = str_replace ("\r\n", "<br />\n", $Body);
            }
            else {
              $Body = str_replace ("\r\n", "\n", $Body);
            }
            $Body = PurgeNewline ($Body);

            /* This trick is to avoid fake meta data */
            $Body = str_replace ('AUTHOR:', ' AUTHOR:', $Body);
            $Body = str_replace ('CATEGORY:', ' CATEGORY:', $Body);
            $Body = str_replace ('TITLE:', ' TITLE:', $Body);

            /* Comments are allowed for this post */
            if (!strcmp ($Comments, 'Enabled')) {
              if (file_exists ($BlogRoot . $DataDir . $PostId . '/comments/disabled'))
                unlink ($BlogRoot . $DataDir . $PostId . '/comments/disabled');
            }

            /* Comments are not allowed */
            else {
              if (!file_exists ($BlogRoot . $DataDir . $PostId . '/comments/disabled'))
                touch ($BlogRoot . $DataDir . $PostId . '/comments/disabled');
            }

            /* Trackbacks are allowed for this post */
            if (!strcmp ($Trackbacks, 'Enabled')) {
              if (file_exists ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled'))
                unlink ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled');
            }

            /* Trackbacks are not allowed */
            else {
              if (!file_exists ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled'))
                touch ($BlogRoot . $DataDir . $PostId . '/trackbacks/disabled');
            }

            /* Create the post file*/
            $File = 'AUTHOR: ' . $AuthorLogin . '
CATEGORY: ' . $Category . '
TITLE: ' . $Title . '
' . $Body . "\n";

            /* Write the post to file */
            LockedFileWrite ($BlogRoot . $DataDir . $PostId . '/post', $File);
          }

          /* Show the form */
          else {
            echo ' <form method="post" action="edit.php?post=' . $PostId . '"><div>
<fieldset>
<legend><strong>Content</strong></legend>
<table style="width: 100%; border: 0">
<tr><td style="width: 30%">
<label for="title">Title</label>
</td><td style="width: 70%">
<input id="title" name="title" type="text" value="' . htmlentities ($Post['title'], ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="category">Category</label>
</td><td style="width: 70%">
<select id="category" name="category" style="width: 100%">' . "\n";

            foreach ($Categories as $Category) {
              echo '<option value="' . $Category['short'] . '"';
              if (!strcmp ($Category['short'], $Post['category'])) {
                echo ' selected="selected"';
              }
              echo '>' . $Category['long'] . '</option>' . "\n";
            }
            echo '</select>
</td></tr>
<tr><td style="width: 30%; vertical-align: top">
<label for="body">Body</label>
</td><td style="width: 70%">
<textarea id="body" name="body" cols="50" rows="10" style="width: 100%">' . htmlentities ($Post['body'], ENT_COMPAT, 'UTF-8') . '</textarea>
</td></tr>
<tr><td style="width: 30%">
&nbsp;
</td><td style="width: 70%">
<label for="preserve_linebreaks">Preserve linebreaks?</label>
<input type="checkbox" name="preserve_linebreaks" id="preserve_linebreaks" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save post" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>

<fieldset>
<legend><strong>Options</strong></legend>
<table style="width: 100%; border: 0">
<tr><td style="width: 30%">
<label for="timestamp">Timestamp</label>
</td><td style="width: 70%">
<input id="timestamp" name="timestamp" type="text" value="' . $PostId . '" />
<label for="edit_timestamp">Edit timestamp?</label>
<input id="edit_timestamp" name="edit_timestamp" type="checkbox" />
</td></tr>
<tr><td style="width: 30%">
<label for="comments">Comments</label>
</td><td style="width: 70%">
<select id="comments" name="comments">
<option value="Enabled"';
          if (CommentsEnabled ($PostId)) {
            echo ' selected="selected"';
          }
          echo '>Enabled</option>
<option value="Disabled"';
          if (!CommentsEnabled ($PostId)) {
            echo ' selected="selected"';
          }
          echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<label for="trackbacks">Trackbacks</label>
</td><td style="width: 70%">
<select id="trackbacks" name="trackbacks">
<option value="Enabled"';
          if (TrackbacksEnabled ($PostId)) {
            echo ' selected="selected"';
          }
          echo '>Enabled</option>
<option value="Disabled"';
          if (!TrackbacksEnabled ($PostId)) {
            echo ' selected="selected"';
          }
          echo '>Disabled</option>
</select>
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save post" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>
      </div></form>' . "\n";
          }
        }

        /* The user can't edit the post */
        else {
          echo '<p>You are not allowed to edit this post.</p>' . "\n";
        }
      }

      /* The post doesn't exist */
      else {
        echo '<p>The post doesn\'t exist.</p>' . "\n";
      }
    }

    /* We are editing an user */
    else if (!strcmp ($Context, 'user')) {

      /* The user exists */
      if (isset ($Users[$Query])) {

        /* The user can edit */
        if ((UserCan ('edit_user')) || (!strcmp ($Query, $UserLogin))) {

          /* The user if submitting the form */
          if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

            /* Redirect to users page */
            header ('Location: users.php');

            $User = $Users[$Query];

            /* Check if the current password was inserted */
            if (isset ($_POST['current_password'])) {

              /* Check the inserted password matches the one in the database */
              if (!strcmp (md5 ($_POST['current_password']), $User['password'])) {

                if (isset ($_POST['password'])) {

                  /* Check the new password was confirmed correctly */
                  if (!strcmp ($_POST['password'], $_POST['confirm_password'])) {
                    $User['password'] = md5 (stripslashes ($_POST['password']));
                  }
                }
              }
            }
            if (isset ($_POST['name'])) {
              $User['name'] = stripslashes ($_POST['name']);
            }
            if (isset ($_POST['link'])) {
              $User['link'] = stripslashes ($_POST['link']);
            }

            /* A user can't edit his own permissions */
            if (strcmp ($User['login'], $UserLogin)) {

              /* Start with no permissions */
              $Perms = '0000000';

              if (isset ($_POST['create_post'])) {
                $Perms[0] = $Perms[0] + 4;
              }
              if (isset ($_POST['edit_post'])) {
                $Perms[0] = $Perms[0] + 2;
              }
              if (isset ($_POST['delete_post'])) {
                $Perms[0] = $Perms[0] + 1;
              }
              if (isset ($_POST['delete_comment'])) {
                $Perms[1] = $Perms[1] + 1; 
              }
              if (isset ($_POST['delete_trackback'])) {
                $Perms[2] = $Perms[2] + 1; 
              }
              if (isset ($_POST['create_category'])) {
                $Perms[3] = $Perms[3] + 4; 
              }
              if (isset ($_POST['edit_category'])) {
                $Perms[3] = $Perms[3] + 2; 
              }
              if (isset ($_POST['delete_category'])) {
                $Perms[3] = $Perms[3] + 1; 
              }
              if (isset ($_POST['create_user'])) {
                $Perms[4] = $Perms[4] + 4; 
              }
              if (isset ($_POST['edit_user'])) {
                $Perms[4] = $Perms[4] + 2; 
              }
              if (isset ($_POST['delete_user'])) {
                $Perms[4] = $Perms[4] + 1; 
              }
              if (isset ($_POST['edit_configuration'])) {
                $Perms[6] = $Perms[6] + 2; 
              }
              $User['perms'] = $Perms;
            }

            /* Save the user, and write the list back to file */
            $Users[$Query] = $User;
            WriteUsers ();
          }

          /* Show the form */
          else {

            /* Get the user */
            $User = $Users[$Query];
            $Perms = $User['perms'];

            /* This part is common for all users */
            echo '<form method="post" action="edit.php?user=' . $User['login'] . '"><div>
<fieldset>
<legend><strong>User info</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
Login
</td><td style="width: 70%">
<input type="text" name="login" id="login" value="' . htmlentities ($User['login'], ENT_COMPAT, 'UTF-8') . '" disabled="disabled" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="name">Name</label>
</td><td style="width: 70%">
<input type="text" id="name" name="name" value="' . htmlentities ($User['name'], ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="link">Link</label>
</td><td style="width: 70%">
<input type="text" id="link" name="link" value="' . htmlentities ($User['link'], ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save user" />
</td></tr>
</table>
</fieldset>' . "\n";

            /* You can't edit your own permission, neither you can edit the
               anonymous user's permissions */
            if ((strcmp ($User['login'], $UserLogin)) && (strcmp ($User['login'], 'anonymous'))) {
              echo '<fieldset>
<legend><strong>Permissions</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
Posts
</td><td style="width: 20%">
<label for="create_post">Create</label>
<input type="checkbox" id="create_post" name="create_post" ';
              if (($Perms[0] == 4) || ($Perms[0] == 5) || ($Perms[0] == 6) || ($Perms[0] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="edit_post">Edit</label>
<input type="checkbox" id="edit_post" name="edit_post" ';
              if (($Perms[0] == 2) || ($Perms[0] == 3) || ($Perms[0] == 6) || ($Perms[0] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="delete_post">Delete</label>
<input type="checkbox" id="delete_post" name="delete_post" ';
              if (($Perms[0] == 1) || ($Perms[0] == 3) || ($Perms[0] == 5) || ($Perms[0] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td></tr>
<tr><td style="width: 30%">
Comments
</td><td style="width: 20%">
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="delete_comment">Delete</label>
<input type="checkbox" id="delete_comment" name="delete_comment" ';
              if (($Perms[1] == 1) || ($Perms[1] == 3) || ($Perms[1] == 5) || ($Perms[1] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td></tr>
<tr><td style="width: 30%">
Trackbacks
</td><td style="width: 20%">
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="delete_trackback">Delete</label>
<input type="checkbox" id="delete_trackback" name="delete_trackback" ';
              if (($Perms[2] == 1) || ($Perms[2] == 3) || ($Perms[2] == 5) || ($Perms[2] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td></tr>
<tr><td style="width: 30%">
Categories
</td><td style="width: 20%">
<label for="create_category">Create</label>
<input type="checkbox" id="create_category" name="create_category" ';
              if (($Perms[3] == 4) || ($Perms[3] == 5) || ($Perms[3] == 6) || ($Perms[3] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="edit_category">Edit</label>
<input type="checkbox" id="edit_category" name="edit_category" ';
              if (($Perms[3] == 2) || ($Perms[3] == 3) || ($Perms[3] == 6) || ($Perms[3] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="delete_category">Delete</label>
<input type="checkbox" id="delete_category" name="delete_category" ';
              if (($Perms[3] == 1) || ($Perms[3] == 3) || ($Perms[3] == 5) || ($Perms[3] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td></tr>
<tr><td style="width: 30%">
Users
</td><td style="width: 20%">
<label for="create_user">Create</label>
<input type="checkbox" id="create_user" name="create_user" ';
              if (($Perms[4] == 4) || ($Perms[4] == 5) || ($Perms[4] == 6) || ($Perms[4] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="edit_user">Edit</label>
<input type="checkbox" id="edit_user" name="edit_user" ';
              if (($Perms[4] == 2) || ($Perms[4] == 3) || ($Perms[4] == 6) || ($Perms[4] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
<label for="delete_user">Delete</label>
<input type="checkbox" id="delete_user" name="delete_user" ';
              if (($Perms[4] == 1) || ($Perms[4] == 3) || ($Perms[4] == 5) || ($Perms[4] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td></tr>
<tr><td style="width: 30%">
Configuration
</td><td style="width: 20%">
</td><td style="width: 20%">
<label for="edit_configuration">Edit</label>
<input type="checkbox" id="edit_configuration" name="edit_configuration" ';
              if (($Perms[6] == 2) || ($Perms[6] == 3) || ($Perms[6] == 6) || ($Perms[6] == 7)) {
                echo 'checked="checked" ';
              }
              echo '/>
</td><td style="width: 20%">
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save user" />
</td></tr>
</table>
</fieldset>' . "\n";
            }

            /* You can't change the password for the anonymous user */
            if (strcmp ($User['login'], 'anonymous')) {
              echo '<fieldset>
<legend><strong>Change password</strong></legend>
<table style="width: 100%; border: 0px">
<tr><td style="width: 30%">
<label for="current_password">Current password</label>
</td><td style="width: 70%">
<input type="password" id="current_password" name="current_password" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="password">New password</label>
</td><td style="width: 70%">
<input type="password" id="password" name="password" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="confirm_password">Confirm new password</label>
</td><td style="width: 70%">
<input type="password" id="confirm_password" name="confirm_password" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save user" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>' . "\n";
            }

            echo '</div></form>' . "\n";
          }
        }

        /* The user is not allowed to perform this action */
        else {
          echo '<p>You are not allowed to edit this user.</p>' . "\n";
        }
      }

      /* The user doesn't exist */
      else {
        echo '<p>The user doesn\' exists.</p>' . "\n";
      }
    }

    /* We are editing a category */
    else if (!strcmp ($Context, 'category')) {

      /* The category exists */
      if (isset ($Categories[$Query])) {

        /* The user can edit the category */
        if (UserCan ('edit_category')) {

          /* The user is submitting the form */
          if (!strcmp ($_SERVER['REQUEST_METHOD'], 'POST')) {

            /* Redirect to categories page */
            header ('Location: categories.php');

            $Category = $Categories[$Query];

            if (isset ($_POST['long'])) {
              $Category['long'] = stripslashes ($_POST['long']);
            }

            /* Save the category and write the list to file */
            $Categories[$Query] = $Category;
            WriteCategories ();
          }

          /* Show the form */
          else {
            $Category = $Categories[$Query];
            echo '<form method="post" action="edit.php?category=' . $Query . '"><div>
<fieldset>
<legend><strong>Category info</strong></legend>
<table style="width: 100%; border: 0">
<tr><td style="width: 30%">
<label for="short">Short name</label>
</td><td style="width: 70%">
<input type="text" id="short" name="long" value="' . htmlentities ($Category['short'], ENT_COMPAT, 'UTF-8') . '" disabled="disabled" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<label for="long">Long name</label>
</td><td style="width: 70%">
<input type="text" id="long" name="long" value="' . htmlentities ($Category['long'], ENT_COMPAT, 'UTF-8') . '" style="width: 100%" />
</td></tr>
<tr><td style="width: 30%">
<input type="submit" value="Save category" />
</td><td style="width: 70%">
&nbsp;
</td></tr>
</table>
</fieldset>
</div></form>' . "\n";
          }
        }

        /* The user can't edit the category */
        else {
          echo '<p>You are not allowed to edit this category.</p>' . "\n";
        }
      }

      /* The category doesn't exist */
      else {
        echo '<p>The category doesn\'t exist.</p>' . "\n";
      }
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
