<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  $ModuleName = 'Show';
  $BlogRoot = '../';
  $TemplateDir = 'admin/template/';
  $PosterVersion = '1.0.12';
  
  /* The user is not logged in: redirect to login page */
  if ((!isset ($_COOKIE['Poster'])) || (!$_COOKIE['Poster'])) {
    header ('Location: index.php');
  }
  else {

    /* Start session */
    session_name ('Poster');
    session_start ();

    /* Include config and functions */
    ob_start ();
    require ($BlogRoot . 'config.php');
    require ($BlogRoot . 'include/poster.php');

    /* Disable error messages if debug is turned off in the config file;
     * otherwise, show all error and warning messages */
    error_reporting (NULL);
    if ($Debug == 1) {
      error_reporting (E_ALL);
    }

    /* Read users and categories */
    $Users = ReadUsers ();
    $Categories = ReadCategories ();

    /* Get some info about the user */
    list ($UserLogin, $UserName, $UserLink, $UserPerms) = UserInfo ();

    /* Read posts, comments and trackbacks */
    $Posts = ReadPosts ();
    $Comments = ReadComments ();
    $Trackbacks = ReadTrackbacks ();

    /* The user is not logged in, or the authentication token is not valid */
    if (!isset ($UserLogin)) {
      header ('Location: logout.php');
    }

    /* Get the number of posts */
    $PostsCount = count ($Posts);

    /* Get the number of comments */
    $CommentsCount = 0;
    if (count ($Comments > 0)) {
      foreach ($Comments as $PostComments) {
        $CommentsCount += count ($PostComments) - 1;
      }
    }

    /* Get the number of trackbacks */
    $TrackbacksCount = 0;
    if (count ($Trackbacks > 0)) {
      foreach ($Trackbacks as $PostTrackbacks) {
        $TrackbacksCount += count ($PostTrackbacks) - 1;
      }
    }

    /* Set some values related to pages */
    if ((isset ($_GET['page'])) && ($_GET['page'])) {
      $PageNumber = stripslashes ($_GET['page']);
    }
    else {
      $PageNumber = 1;
    }

    /* The number of available pages */
    if ($PostsCount <= $PostsNumber) {
      $PagesCount = 1;
    }
    else {
      if (($PostsCount % $PostsNumber) == 0) {
        $PagesCount = $PostsCount / $PostsNumber;
      }
      else {
        $PagesCount = $PostsCount - ($PostsCount % $PostsNumber);
        $PagesCount = ($PagesCount / $PostsNumber) + 1;
      }
    }

    /* FIXME I *really* have to find a better way to do make this work */
    /* Set this script as BlogUrl before creating links, so the links point
     * the admin page and not to the blog */
    $OldUrl = $BlogUrl;
    $BlogUrl = 'show.php';

    /* Previous and next page */
    if (($PageNumber > 1) && ($PageNumber < ($PagesCount + 1))) {
      $PreviousPage = CreateBlogLink ('page=' . ($PageNumber - 1));
    }
    if (($PageNumber > 0) && ($PageNumber < $PagesCount)) {
      $NextPage = CreateBlogLink ('page=' . ($PageNumber + 1));
    }

    /* First and last page */
    $FirstPage = CreateBlogLink ('page=1');
    $LastPage = CreateBlogLink ('page=' . $PagesCount);

    /* Back to the true $BlogUrl */
    $BlogUrl = $OldUrl;

    /* Get the post list */
    $Context = GetContext ();
    $Query = GetQuery ($Context);
    $PostsList = GetPostsList ($Context, $Query);
  
    /* Show header */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'header.php');
    $Header = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Header, NULL);

    /* Show posts */
    $i = 0;
    while ((isset ($PostsList[$i])) && ($PostsList[$i])) {
      $PostId = $PostsList[$i];
      ShowPost ($PostId);

      /* If there are other posts after this one, show a separator */
      if (isset ($PostsList[$i + 1])) {
        ob_start ();
        include ($BlogRoot . $TemplateDir . 'post-post_spacer.php');
        $Spacer = ob_get_contents ();
        ob_end_clean ();
        echo TagsReplace ($Spacer, NULL);
      }

      /* We are showing a post along with its comments */
      if (!strcmp ($Context, 'comment')) {

        /* Check there is at least one comment for this post */
        if (GetCommentsNumber ($PostId) > 0) {

          /* Show a spacer and all the comments */
          ob_start ();
          include ($BlogRoot . $TemplateDir . 'post-comments_spacer.php');
          $Spacer = ob_get_contents ();
          ob_end_clean ();
          echo TagsReplace ($Spacer, NULL);

          ShowComments ($PostId);
        }

        /* Check wether comments are enabled for this post */
        if (CommentsEnabled ($PostId)) {

          /* Show a spacer and the comment submitting form */
          ob_start ();
          include ($BlogRoot . $TemplateDir . 'comments-form_spacer.php');
          $Spacer = ob_get_contents ();
          ob_end_clean ();
          echo TagsReplace ($Spacer, NULL);

          ShowCommentForm ($PostId);
        }
      }

      /* We are showing a post along with its trackbacks */
      if (!strcmp ($Context, 'trackback')) {

        /* Check there is at least one trackback */
        if (GetTrackbacksNumber ($PostId) > 0) {

          /* Show a spacer and all the trackbacks */
          ob_start ();
          include ($BlogRoot . $TemplateDir . 'post-trackbacks_spacer.php');
          $Spacer = ob_get_contents ();
          ob_end_clean ();
          echo TagsReplace ($Spacer, NULL);

          ShowTrackbacks ($PostId);
        }

        /* Check wether trackbacks are enabled for this post */
        if (TrackbacksEnabled ($PostId)) {

          /* Show a spacer and the trackback submitting form */
          ob_start ();
          include ($BlogRoot . $TemplateDir . 'trackbacks-form_spacer.php');
          $Spacer = ob_get_contents ();
          ob_end_clean ();
          echo TagsReplace ($Spacer, NULL);

         ShowTrackbackForm ($PostId);
        } 
      }

      $i++;
    }

    /* Check wether we should show the spacer */
    if ((!strcmp ($Context, 'index')) || (!strcmp ($Context, 'page'))) {
      if ($PagesCount > 1) {

        /* Show a spacer and the pager */
        ob_start ();
        include ($BlogRoot . $TemplateDir . 'posts-pager_spacer.php');
        $Spacer = ob_get_contents ();
        ob_end_clean ();
        echo TagsReplace ($Spacer, NULL);

        ob_start ();
        include ($BlogRoot . $TemplateDir . 'pager.php');
        $Pager = ob_get_contents ();
        ob_end_clean ();
        echo TagsReplace ($Pager, NULL);
      }
    }

    /* Show footer */
    ob_start ();
    include ($BlogRoot . $TemplateDir . 'footer.php');
    $Footer = ob_get_contents ();
    ob_end_clean ();
    echo TagsReplace ($Footer, NULL);
    
    ob_end_flush ();
  }
?>
