<?php
  /*  Poster - Simple and light blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  function GetPostsList ($Context, $Query)
  {
    global $BlogRoot, $DataDir, $Posts, $Categories, $Users, $PostsNumber;

    /* Create an empty list */
    $PostsList = array ();

    if (!strcmp ($Context, 'archive')) {
      foreach ($Posts as $PostId) {

      /* Check the query is not empty */
      if (strcmp ($Query, '')) {

          /* Check if the post's id matches the query */
          if (preg_match ('/^' . $Query . '.*/', $PostId)) {
            $PostsList[] = $PostId;
          }
        }
      }
    }
    else if (!strcmp ($Context, 'category')) {

      /* Check the category exists */
      if (isset ($Categories[$Query])) {
        foreach ($Posts as $PostId) {

          /* Parse the post to obtain the category */
          $Post = ParsePost ($PostId);

          /* If the category of the post is the one we're looking for, add
           * the post to the list */
          if (!strcmp ($Post['category'], $Query)) {
            $PostsList[] = $PostId;
          }
        }
      }
    }
    else if (!strcmp ($Context, 'author')) {

      /* Check the user exists */
      if (isset ($Users[$Query])) {
        foreach ($Posts as $PostId) {

          /* Parse the post to obtain the author's name */
          $Post = ParsePost ($PostId);

          /* If the name of the author is the one we're looking for, add the
           * post to the list */
          if (!strcmp ($Post['author'], $Query)) {
            $PostsList[] = $PostId;
          }
        }
      }
    }
    else if (!strcmp ($Context, 'page')) {

      /* Get the position of the first post in the page */
      $i = ($Query - 1) * $PostsNumber;

      /* Repeat $PostNumber times, to get the right amount of posts */
      for (; $i < ($Query * $PostsNumber); $i++) {

        /* Check the post exists and add it to the list */
        if (isset ($Posts[$i])) {
          $PostsList[] = $Posts[$i];
        }
      }
    }
    else if (!strcmp ($Context, 'index')) {

      /* Take the first $PostsNumber posts */
      for ($i = 0; $i < $PostsNumber; $i++) {

        /* Check the post exists before adding it to the list */
        if (isset ($Posts[$i])) {
          $PostsList[] = $Posts[$i];
        }
      }
    }
    else if (!strcmp ($Context, 'trackback')) {

      /* Check the post exist and add it to the list */
      if (IsPost ($Query)) {
        $PostsList[] = $Query;
      }
    }
    else if (!strcmp ($Context, 'comment')) {

      /* Check the post exists and add it to the list */
      if (IsPost ($Query)) {
        $PostsList[] = $Query;
      }
    }
    else if (!strcmp ($Context, 'post')) {

      /* Check the post exists and add it to the list */
      if (IsPost ($Query)) {
        $PostsList[] = $Query;
      }
    }

    return $PostsList;
  }
?>
