<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  function SaveComment ($PostId)
  {
    global $BlogRoot, $BlogUrl, $DataDir, $AllowedTags, $UserLogin;
    global $CaptchaFilter, $CaptchaSecretKey, $BlacklistFilter;

    $Body = '';
    $AuthorName = '';
    $AuthorLink = '';
    $Security = '';
    $Secret = '';
    $Check = TRUE;

    /* Get comment information */
    if (isset ($_POST['body'])) {
      $Body = stripslashes ($_POST['body']);
    }
    if (isset ($_POST['name'])) {
      $AuthorName = stripslashes ($_POST['name']);
    }
    if (isset ($_POST['link'])) {
      $AuthorLink = stripslashes ($_POST['link']);
    }
    if (isset ($_POST['security'])) {
      $Security = stripslashes ($_POST['security']);
    }
    if (isset ($_POST['secret'])) {
      $Secret = stripslashes ($_POST['secret']);
    }

    /* Do nothing if comments are disabled for this post */
    if (!CommentsEnabled ($PostId)) {
      $Check = FALSE;
    }

    /* If there is no comment body, or it is empty, just exit */
    if ($Check) {
      if (!$Body) {
        $Check = FALSE;
      }
    }

    /* We use UNIX end-of-line (\n) everywhere, but textareas use DOS
     * end-of-line (\r\n), so we have to fix this before saving to file.
     * Also, if the `preserve_linebreaks' checkbox is active, we need to
     * preserve line breaks, so we add a <br /> before each one. This is the
     * default behavior starting from Poster 1.0.6 */
    if ($Check) {
      if (isset ($_POST['preserve_linebreaks'])) {
        $Body = str_replace ("\r\n", "<br />\n", $Body);
      }
      else {
        $Body = str_replace ("\r\n", "\n", $Body);
      }

      /* Purge trailing newline from body if necessary */
      $Body = PurgeNewline ($Body);
    }

    /* Check if the captcha filter is enabled */
    if ($Check) {
      if (!strcmp ($CaptchaFilter, 'Enabled')) {

        /* Check the security word and the secret are present and not emprty */
        if ((!$Security) || (!$Secret)) {
          $Check = FALSE;
        }

        /* Decode the secret and check it matches the security word */
        if ($Check) {
          $Word = CaptchaDecrypt ($Secret);
          if (strcmp ($Security, $Word)) {
            $Check = FALSE;
          }
        }
      }
    }

    /* Check if the blacklist filter is enabled */
    if ($Check) {
      if (!strcmp ($BlacklistFilter, 'Enabled')) {

        /* Load the blacklist from file */
        $Blacklist = ReadBlacklist ();
        $Blocked = FALSE;

        for ($i = 0; $i < count ($Blacklist); $i++) {

          /* If the body matches a blacklisted expression, block it */
          if (preg_match ('/' . $Blacklist[$i] . '/i', $Body)) {
            $Blocked = TRUE;
            break;
          }
        }

        /* Stop processing if the comment was blocked */
        if ($Blocked) {
          $Check = FALSE;
        }
      }
    }

    /* Everything is fine, go ahead and save the comment */
    if ($Check) {

      /* Create the comment's id using date and time */
      $Now = strtotime (TimeOffsetString (), time ());
      $CommentId = strftime ('%Y%m%d%H%M%S', $Now);

      /* If the user is logged in, we just use his login */
      if ($UserLogin) {
        $AuthorName = $UserLogin;
      }
      else {

        /* If no name is given, use the anonymous user */
        if (!$AuthorName) {
          $AuthorName = 'anonymous';
        }
        else {

          /* If no link is given, use the comment's permalink instead */
          if ((!strcmp ($AuthorLink, '')) || (!strcmp ($AuthorLink, 'http://'))) {
            $AuthorLink = CreateBlogLink ('comment=' . $PostId .
                                          '#_' . $CommentId);
          }

          /* Escape special chars */
          $AuthorName = str_replace ('\\', '\\\\', $AuthorName);
          $AuthorName = str_replace (':', '\\:', $AuthorName);
          $AuthorLink = str_replace ('\\', '\\\\', $AuthorLink);
          $AuthorLink = str_replace (':', '\\:', $AuthorLink);

          /* Append the link to the author's name */
          $AuthorName .= ':' . $AuthorLink;
        }
      }

      /* This trick is to avoid fake meta-data */
      $Body = str_replace ("\n" . 'AUTHOR: ', "\n" . ' AUTHOR: ', $Body);

      /* Remove non-allowed HTML tags */
      $Body = strip_tags ($Body, $AllowedTags);

      /* Put together the final content of the file */
      $File = 'AUTHOR: ' . $AuthorName . '
' . $Body . "\n";

      /* Write the comment to file */
      $Check = LockedFileWrite ($BlogRoot . $DataDir . $PostId . '/comments/' .
                                $CommentId, $File);
    }

    return $Check;
  }
?>
