<?php
  /*  Poster - Simple and light weight blog engine
   *  Copyright (C) 2004-2009  Andrea Bolognani <eof@kiyuko.org>
   *
   *  This program is free software; you can redistribute it and/or modify
   *  it under the terms of the GNU General Public License as published by
   *  the Free Software Foundation; either version 2 of the License, or
   *  (at your option) any later version.
   *
   *  This program is distributed in the hope that it will be useful,
   *  but WITHOUT ANY WARRANTY; without even the implied warranty of
   *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   *  GNU General Public License for more details.
   *
   *  You should have received a copy of the GNU General Public License along
   *  with this program; if not, write to the Free Software Foundation, Inc.,
   *  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
   *
   *  Homepage: http://kiyuko.org/software/poster
   */

  function ShowComments ($PostId)
  {
    global $BlogRoot, $TemplateDir, $Users, $Comments;

    /* Get the list of all the comments for this post */
    $PostComments = $Comments[$PostId];
    unset ($PostComments['post_id']);

    /* Create post permalink */
    $PostPermalink = CreateBlogLink ('comment=' . $PostId);

    /* This code is repeated for each comment */
    for ($i = 0; $i < count ($PostComments); $i++) {

      $CommentAuthorLogin = '';
      $CommentAuthorName = '';
      $CommentAuthorLink = '';
      $CommentBody = '';

      $CommentId = $PostComments[$i];

      /* Date/time the comment was written */
      $CommentYear = substr ($CommentId, 0, 4);
      $CommentMonth = substr ($CommentId, 4, 2);
      $CommentDay = substr ($CommentId, 6, 2);
      $CommentHour = substr ($CommentId, 8, 2);
      $CommentMinute = substr ($CommentId, 10, 2);
      $CommentSecond = substr ($CommentId, 12, 2);
      $CommentPermalink = $PostPermalink . '#_' . $CommentId;

      /* Parse comment */
      $Comment = ParseComment ($PostId, $CommentId);

      /* Get author and body of the comment */
      $CommentAuthorName = $Comment['author'];
      $CommentBody = $Comment['body'];

      /* The author of the comment is an user */
      if (isset ($Users[$CommentAuthorName])) {
        $CommentAuthorLogin = $CommentAuthorName;
        $User = $Users[$CommentAuthorName];
        $CommentAuthorName = $User['name'];
        $CommentAuthorLink = $User['link'];

        /* Create the permalink for the author */
        $CommentAuthorPermalink = CreateBlogLink ('author=' . $User['login']);
      }

      /* The author of the comment is not an user */
      else {

        /* Create semi-random strings to use in place of special chars */
        $Colon = '__COLON_' . RandomString (8) . '__';
        $Backslash = '__BACKSLASH_' . RandomString (8) . '__';

        /* Replace special chars */
        $Line = str_replace ('\\:', $Colon, $CommentAuthorName);
        $Line = str_replace ('\\\\', $Backslash, $Line);

        /* Get the tokens */
        list ($CommentAuthorName, $CommentAuthorLink) = explode (':', $Line);

        /* Restore special chars */
        $CommentAuthorName = str_replace ($Colon, ':', $CommentAuthorName);
        $CommentAuthorName = str_replace ($Backslash, '\\', $CommentAuthorName);
        $CommentAuthorLink = str_replace ($Colon, ':', $CommentAuthorLink);
        $CommentAuthorLink = str_replace ($Backslash, '\\', $CommentAuthorLink);

        /* Since the author is not an user, there is no permalink. Use the
         * comment's permalink instead */
        $CommentAuthorPermalink = $CommentPermalink;
      }

      /* Create the array used for tags replacing */
      $V = array ('p.id' => $PostId,
                  'p.plink' => $PostPermalink,
                  'c.id' => $CommentId,
                  'c.year' => $CommentYear,
                  'c.month' => $CommentMonth,
                  'c.day' => $CommentDay,
                  'c.hour' => $CommentHour,
                  'c.min' => $CommentMinute,
                  'c.sec' => $CommentSecond,
                  'c.plink' => $CommentPermalink,
                  'c.a_name' => $CommentAuthorName,
                  'c.a_link' => $CommentAuthorLink,
                  'c.a_plink' => $CommentAuthorPermalink,
                  'c.body' => $CommentBody);

      /* Show comment */
      ob_start ();
      include ($BlogRoot . $TemplateDir . 'comment.php');
      $Comment = ob_get_contents ();
      ob_end_clean ();
      echo TagsReplace ($Comment, $V);

      /* if there are other comments, show a spacer */
      if ($i < (count ($PostComments) - 1)) {

        /* Show spacer */
        ob_start ();
        include ($BlogRoot . $TemplateDir . 'comment-comment_spacer.php');
        $Spacer = ob_get_contents ();
        ob_end_clean ();
        echo TagsReplace ($Spacer, NULL);
      }
    }
  }
?>
